'use strict';
const Subscription = require('egg').Subscription;

class OrderCommission extends Subscription {
  /**
   * cron
   * *    *    *    *    *    *
   * ┬    ┬    ┬    ┬    ┬    ┬
   * │    │    │    │    │    |
   * │    │    │    │    │    └ day of week (0 - 7) (0 or 7 is Sun)
   * │    │    │    │    └───── month (1 - 12)
   * │    │    │    └────────── day of month (1 - 31)
   * │    │    └─────────────── hour (0 - 23)
   * │    └──────────────────── minute (0 - 59)
   * └───────────────────────── second (0 - 59, optional)
   * @returns {{cron: string, type: string}}
   */
  // 通过 schedule 属性来设置定时任务的执行间隔等配置
  static get schedule() {
    return {
      // interval: '1m', // 1 分钟间隔
      // interval: '3s', // 10s
      // cron: '0 0 */3 * * *', // 每三小时准点执行一次
      cron: '0 0 1 * * *', // 每天凌晨1点准点执行一次
      type: 'all', // 指定所有的 worker 都需要执行
    };
  }

  // subscribe 是真正定时任务执行时被运行的函数
  async subscribe() {
    /* await this.service.inviter.executeSchedule();*/
  }

}

module.exports = OrderCommission;
